.. image:: iman_logo.png
   :width: 600
   :align: center
   :alt: GeoComPy logo

|
|
|

***********************************************
Welcome to the **Instrumentman** documentation!
***********************************************

Collection of CLI surveying instrument automation tools, based on the
protocols implemented in the
`GeoComPy <https://github.com/MrClock8163/GeoComPy>`_ package.

Links
=====

- :si-icon:`material/text-box-multiple` `Documentation <https://instrumentman.readthedocs.io>`_
- :si-icon:`material/download` `Download <https://pypi.org/project/instrumentman/>`_
- :si-icon:`material/github` `GitHub <https://github.com/MrClock8163/Instrumentman>`_

Content
=======

.. toctree::
    :maxdepth: 1

    overview
    changelog

.. toctree::
    :maxdepth: 1
    :caption: Applications

    about
    commands/morse
    commands/terminal
    commands/targets/index
    commands/sets/index
    commands/inclination/index
    commands/protocoltest/index
    commands/files/index
    commands/data/index
    commands/jobs/index
    commands/settings/index

Indices

* :ref:`genindex`
* :ref:`modindex`
